@@ -209,6 +209,21 @@ def alerts_query(context, query):
         format_table.add_row([alert['message'], alert['tags'], alert['integration']['type'], alert['createdAt']])
     print(format_table)
 
+@bootstrapper.group()
+@click.pass_context
+def version(context):  # pylint: disable=unused-argument
+    """Sub-command for Opsgeniecli. This function is a placeholder to maintain the correct hierarchy for the cli"""
+    pass
+
+
+@version.command(name='show')
+@click.pass_context
+def show_version(context):
+    basepath = os.path.dirname(__file__)
+    filepath = os.path.abspath(os.path.join(basepath, "..", ".VERSION"))
+    with open(filepath, 'r') as file:
+        data = file.read().replace('\n', '')
+    print(f"Opsgeniecli version: {data}")
 
 @alerts.command(name='list')
 @click.option('--active', default=False, is_flag=True)
@@ -262,7 +277,7 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
                     format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'],
                                           alert_dt.to_datetime_string(), item['tags'], item['source'], item['integration']['name']])
                 else:
-                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'], created_at])
+                    format_table.add_row([item['id'], item['message'], item['status'], item['acknowledged'], alert_dt.to_datetime_string()])
         elif active:
             if item['status'] == 'open' and not item['acknowledged']:
                 created_at = ((pendulum.parse(item['createdAt'])).in_tz('Europe/Amsterdam')).to_datetime_string()
